--- this saves the current attached equipment to a template file
-- @param user - the user using the equipment editor
function ExportEquipmentToXml(user,object)
	--to help prevent bad templates, check if object is a armor/shield/weapon
	if not(object:HasObjVar("ArmorType") or object:HasObjVar("WeaponType") or object:HasObjVar("ShieldType")) then 
		user:SystemMessage("This is not equipment,Save Failed!","event")
		return 
	end

	-- create local objects and variables
	local xmlRoot = xml.new("ObjectTemplate")
	local entry = nil
	local objectComponents = nil
	local scriptComponents = nil
	local directory = "mods/"..GetModName().."/templates/"
	local fileName = string.lower(StripColorFromString(object:GetName()))
	local fileStream = nil
	local saveInfo = ""

	-- set up the object template elements
	-- name
	xmlRoot:append("Name")[1] = object:GetName()
	-- clientid
	xmlRoot:append("ClientId")[1] = object:GetIconId()
	-- hue
	xmlRoot:append("Hue")[1] = object:GetHue()
	-- color only if its not FFFFFF
	if(object:GetColor() ~= "FFFFFF") then
		xmlRoot:append("Color")[1]=object:GetColor()
	end
	-- weight
	entry = xml.new("SharedStateEntry")
	entry["name"] = "Weight"
	entry["type"] = "int"
	entry["value"] = GetWeight(object)
	xmlRoot:append(entry)
	
	-- set up the object components	
	objectComponents = xml.new("ObjectVariableComponent") 
	-- which type of equipment is this? weapon,armor or shield
	if(object:HasObjVar("WeaponType")) then 
		entry = xml.new("StringVariable")
		entry["Name"] = "WeaponType"
		entry[1] = object:GetObjVar("WeaponType")
		objectComponents:append(entry)
	elseif(object:HasObjVar("ShieldType")) then 
		entry = xml.new("StringVariable")
		entry["Name"] = "ShieldType"
		entry[1] = object:GetObjVar("ShieldType")
		objectComponents:append(entry)	
	elseif(object:HasObjVar("ArmorType")) then 
		entry = xml.new("StringVariable")
		entry["Name"] = "ArmorType"
		entry[1] = object:GetObjVar("ArmorType")
		objectComponents:append(entry)	
	end
	-- if it has a armor bonus from crafting, apply it to the save
	if(object:HasObjVar("ArmorBonus")) then
		entry = xml.new("DoubleVariable")
		entry["Name"] = "ArmorBonus"
		entry[1] = object:GetObjVar("ArmorBonus")
		objectComponents:append(entry)			
	end
	-- if it has a attack bonus from crafting, apply it to the save
	if(object:HasObjVar("AttackBonus")) then
		entry = xml.new("DoubleVariable")
		entry["Name"] = "AttackBonus"
		entry[1] = object:GetObjVar("AttackBonus")
		objectComponents:append(entry)			
	end
	-- durability	
	entry = xml.new("DoubleVariable")
	entry["Name"] = "MaxDurability"
	entry[1] = object:GetObjVar("MaxDurability")	
	objectComponents:append(entry)
	xmlRoot:append(objectComponents)

	-- set up the script components
	-- does the equipment have enchants, if so generate the xml data
	if(object:HasObjVar("Enchants")) then
		scriptComponents = xml.new("ScriptEngineComponent")
		entry = xml.new("LuaModule")
		entry["Name"] = "set_initializer_variables"
		local initializer = xml.new("Initializer")
		initializer[1] = BuildEnchantTable(object)
		entry:append(initializer)
		scriptComponents:append(entry)
		xmlRoot:append(scriptComponents)
	end
	
	-- extract the &quote and replace with a "
	saveInfo = string.gsub(tostring(xmlRoot),"&quot;","\"")

	-- save the equipment to xml
	-- generate file name
	fileName = string.gsub(fileName," ", "_")
	fileName = fileName .. ".xml"
	fileName = directory .. fileName
	-- open file and save
	fileStream = io.open(fileName,"w")
	fileStream:write(saveInfo)
	fileStream:close()
	
	-- reload tempmlates so we can access our new item
	ReloadTemplates()

	-- aleart the user everything went okay
	user:SystemMessage(object:GetName() .. " saved to xml","event")
end	

--- this builds the enchant string for saving in the xml template file
-- @param object - the equipment that holds the enchants objvar
function BuildEnchantTable(object)
	local build = "\n\t\t\t{\t\n\t\t\t\tEnchants =\n"
	build = build .. "\t\t\t\t{\n"
	for key,value in pairs(object:GetObjVar("Enchants")) do
		build = build .. "\t\t\t\t\t{ essenceName = \""..value.essenceName.."\", essenceModifier = " .. value.essenceModifier .. " },\n"
	end
	build = build .. "\t\t\t\t}\n"
	build = build .. "\t\t\t}\n\t\t\t"
	return build
end